@@ -40,6 +40,12 @@ pub struct Config {
     /// configuration (trivial with multigraph plugins), you may want
     /// to increase this.
     pub cfgsize: usize,
+
+    /// Size of buffer for BufWriter for [MuninPlugin::fetch](super::MuninPlugin::fetch).
+    ///
+    /// Defaults to 8192, but if the plugin outputs large datasets, it
+    /// is useful to increase this.
+    pub fetchsize: usize,
 }
 
 impl Config {
@@ -81,6 +87,43 @@ impl Default for Config {
             daemonize: false,
             pidfile: statedir.join("munin-plugin.pid"),
             cfgsize: 8192,
+            fetchsize: 8192,
         }
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+    use std::path::PathBuf;
+
+    #[test]
+    fn test_modconfig() {
+        // Whole set of defaults
+        let config = Config {
+            ..Default::default()
+        };
+        assert_eq!(
+            config.plugin_name,
+            String::from("Simple munin plugin in Rust")
+        );
+
+        // Use defaults (except for name)
+        let mut config2 = Config {
+            plugin_name: String::from("Lala"),
+            ..Default::default()
+        };
+        // Is plugin name as given?
+        assert_eq!(config2.plugin_name, String::from("Lala"));
+        // Defaults as expected?
+        assert_eq!(config2.daemonize, false);
+        assert_eq!(config2.fetchsize, 8192);
+
+        config2.pidfile = PathBuf::new();
+        config2.pidfile.push(&config2.plugin_statedir);
+        config2.pidfile.push(String::from("Lala.pid"));
+
+        let config3 = Config::new(String::from("Lala"));
+        assert_eq!(config2, config3);
+    }
+}
